The function gives control over the desired joins in order to bring all projects together into one data.frame. The joins are read left-to-right. An example can be found under examples on how to structure the list.
The function gives control over the desired joins in order to bring all projects together into one data.frame. The joins are read left-to-right. An example can be found under examples on how to structure the list.